@@ -31,8 +31,7 @@ from docopt import docopt
 
 
 def parse_block(
-    lines: ty.Iterable[str],
-    column: int = -1
+    lines: ty.Iterable[str], column: int = -1
 ) -> ty.Dict[str, ty.List[ty.Tuple[str, str]]]:
     '''
     Parse a bloc (≈sentence) in the CoNLL format, return entities as mappings
@@ -43,8 +42,8 @@ def parse_block(
     # We have to keep track of the order in which the entites are created (i.e.) the begining of
     # their first mention, since it will be used to determine which entity gets the mention in case
     # of duplication
-    entities = OrderedDict()
-    dangling = defaultdict(list)
+    entities: ty.Dict[str, ty.List[ty.Tuple[str, str]]] = OrderedDict()
+    dangling: ty.Dict[str, ty.List[str]] = defaultdict(list)
     for i, l in enumerate(lines):
         row = l.split()
 
@@ -73,14 +72,16 @@ def parse_block(
                 raise ValueError(f'Unbalanced parentheses at line {i}: {l!r}')
             entities[m.group(1)].append((start, row_n))
     if any(dangling.values()):
-        raise ValueError(f'Dangling mentions at line {i}: {[e for e, v in dangling.items() if e]}')
+        raise ValueError(
+            f'Dangling mentions at line {i}: {[e for e, v in dangling.items() if e]}'
+        )
 
     return entities
 
 
 def split_blocks(lines: ty.Iterable[str]) -> ty.Iterable[ty.List[str]]:
     '''Split blocks in a CoNLL document.'''
-    buffer = []
+    buffer: ty.List[str] = []
     for l in lines:
         if not l or l.isspace():
             yield buffer
@@ -100,23 +101,27 @@ def parse_document(
     entity_id → [(block_number, mention_start, mention_end), …]
     ```
     '''
-    entities = OrderedDict()
+    entities: ty.Dict[str, ty.List[ty.Tuple[int, str, str]]] = OrderedDict()
     for i, block in enumerate(split_blocks(lines)):
         try:
             block_entities = parse_block(block)
         except ValueError as e:
             raise ValueError(
-                'Parse error in block {i}:\n{e}\n{block}'.format(i=i, e=e,
-                                                                 block="\n".join(block)))
+                'Parse error in block {i}:\n{e}\n{block}'.format(
+                    i=i, e=e, block="\n".join(block)
+                )
+            )
         # Merge this block entities
-        for e, mentions in block_entities.items():
-            entities.setdefault(e, []).extend((i, start, end) for start, end in mentions)
+        for ent, mentions in block_entities.items():
+            entities.setdefault(ent, []).extend(
+                (i, start, end) for start, end in mentions
+            )
 
     # Deduplicate mentions : if a mention is in several entities, leave only to the entity that
     # appeared first. If a mention appears several time in an entity, leave it only once
-    seen = set()
+    seen: ty.Set[ty.Tuple[int, str, str]] = set()
     for ent, men in entities.items():
-        men = sorted((set(men)-seen))
+        men = sorted((set(men) - seen))
         if not men:
             del entities[ent]
         entities[ent] = men
@@ -125,8 +130,7 @@ def parse_document(
 
 
 def parse_file(
-    lines: ty.Iterable[str],
-    column: int = -1,
+    lines: ty.Iterable[str], column: int = -1
 ) -> ty.Iterable[ty.Tuple[str, ty.Dict[str, ty.List[ty.Tuple[int, str, str]]]]]:
     '''
     Parse a CoNLL file, return document as tuples `(document_name, entities)` where
@@ -135,7 +139,7 @@ def parse_file(
     entity_id → [(block_number, mention_start, mention_end), …]
     ```
     '''
-    buffer = []
+    buffer: ty.List[str] = []
     for l in lines:
         if l.startswith('#'):
             m = re.match(r'#\s*begin document \((.*?)\);(\s*part (.*))?', l)
@@ -156,14 +160,17 @@ def parse_file(
 
 # Thanks http://stackoverflow.com/a/17603000/760767
 @contextlib.contextmanager
-def smart_open(filename: str = None, mode: str = 'r', *args, **kwargs):
-    '''Open files and i/o streams transparently.'''
-    if filename == '-':
-        if 'r' in mode:
+def smart_open(
+    filename: ty.Union[str, pathlib.Path], mode: str = "r", *args, **kwargs
+) -> ty.Generator[ty.IO, None, None]:
+    """Open files and i/o streams transparently."""
+    fh: ty.IO
+    if filename == "-":
+        if "r" in mode:
             stream = sys.stdin
         else:
             stream = sys.stdout
-        if 'b' in mode:
+        if "b" in mode:
             fh = stream.buffer
         else:
             fh = stream
@@ -191,25 +198,24 @@ def main_entry_point(argv=None):
     else:
         arguments['<out-dir>'] = pathlib.Path(arguments['<out-dir>'])
 
-    if arguments['<conll-file>'] == '-':
-        file_name = 'stdin'
-    else:
-        file_name = pathlib.Path(arguments['<conll-file>']).name
     with smart_open(arguments['<conll-file>']) as in_stream:
         documents = list(parse_file((l.strip() for l in in_stream)))
 
     for name, entities in documents:
         sanitized_name = name.replace('/', '_')
-        out_path = arguments['<out-dir>']/f'{sanitized_name}.json'
+        out_path = arguments['<out-dir>'] / f'{sanitized_name}.json'
         with out_path.open('w') as out_stream:
             json.dump(
                 {
                     'name': name,
                     'type': 'clusters',
-                    'clusters': {e: [f'{block}.{start}-{end}' for block, start, end in c]
-                                 for e, c in entities.items()},
+                    'clusters': {
+                        e: [f'{block}.{start}-{end}' for block, start, end in c]
+                        for e, c in entities.items()
+                    },
                 },
-                out_stream)
+                out_stream,
+            )
 
 
 if __name__ == '__main__':
